# Administrator documentation

This page provides information about how to create and maintain an installation of DiracX.

- You're a user of a DiracX installation looking for how to submit jobs, access data or similar. See the [User Guide](../user/index.md).
- You're instead looking to develop software which uses DiracX programmatically, e.g. to submit jobs.
    Instead check out the user documentation on [programmatic access](../user/reference/programmatic-usage/index.md).
- You already know how to manage DiracX and are looking for specific information, see the sidebar on the left for more specific or in-depth documentation.
